@@ -8,13 +8,7 @@ import jsii
 import publication
 import typing_extensions
 
-from typeguard import check_type
-
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_lambda_event_sources._jsii
-import aws_cdk.aws_sqs._jsii
-import aws_cdk.core._jsii
+import aws_cdk._jsii
 import aws_solutions_constructs.aws_lambda_sqs._jsii
 import aws_solutions_constructs.aws_sqs_lambda._jsii
 import aws_solutions_constructs.core._jsii
@@ -22,9 +16,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-lambda-sqs-lambda",
-    "1.181.1",
+    "2.0.0",
     __name__[0:-6],
-    "aws-lambda-sqs-lambda@1.181.1.jsii.tgz",
+    "aws-lambda-sqs-lambda@2.0.0.jsii.tgz",
 )
 
 __all__ = [
